@@ -24,7 +24,7 @@
 
 */
 
-#include "config.h"
+#include "xdvi-config.h"
 #if defined(XHDVI) || defined(HTEX)
 #include <kpathsea/c-ctype.h>
 #include <kpathsea/c-fopen.h>
