@@ -24,6 +24,10 @@
  *         erik@sra.co.jp
  */
 
+#ifdef HAVE_CONFIG_H
+#include "c-auto.h"
+#endif
+
 #if !defined (NOSELFILE) && !defined (NOTOOL) /* for xdvik */
 
 #include <stdio.h>
